pub fn sin_with(x: &[f32], implementation: F32Transcendental, out: &mut [f32])Expand description
Fills out with sin(x) under the selected implementation.
Panics
Panics if out is not the same length as x.
pub fn sin_with(x: &[f32], implementation: F32Transcendental, out: &mut [f32])Fills out with sin(x) under the selected implementation.
Panics if out is not the same length as x.